@@ -15,10 +15,12 @@
 #include <memory>
 #include <qstringliteral.h>
 
+#include "gifencoder_p.h"
 #include "h264vaapiencoder_p.h"
 #include "libopenh264encoder_p.h"
 #include "libvpxencoder_p.h"
 #include "libvpxvp9encoder_p.h"
+#include "libwebpencoder_p.h"
 #include "libx264encoder_p.h"
 
 extern "C" {
@@ -404,6 +406,25 @@ std::unique_ptr<Encoder> PipeWireProduce::makeEncoder()
         }
         break;
     }
+    case PipeWireBaseEncodedStream::Gif: {
+        if (forcedEncoder.isNull() || forcedEncoder == u"gif") {
+            auto encoder = std::make_unique<GifEncoder>(this);
+            if (encoder->initialize(size)) {
+                return encoder;
+            }
+        }
+        break;
+    }
+    case PipeWireBaseEncodedStream::WebP: {
+        if (forcedEncoder.isNull() || forcedEncoder == u"libwebp") {
+            auto encoder = std::make_unique<LibWebPEncoder>(this);
+            encoder->setQuality(m_quality);
+            if (encoder->initialize(size)) {
+                return encoder;
+            }
+        }
+        break;
+    }
     default:
         qCWarning(PIPEWIRERECORD_LOGGING) << "Unknown encoder type" << m_encoderType;
     }
